Geminix.V1beta.AttributionSourceId (geminix v0.2.0)
Identifier for the source contributing to this attribution.
Fields:
:grounding_passage(Geminix.V1beta.GroundingPassageId.t/0) - Identifier for an inline passage.:semantic_retriever_chunk(Geminix.V1beta.SemanticRetrieverChunk.t/0) - Identifier for aChunkfetched via Semantic Retriever.
Summary
Functions
Create a Geminix.V1beta.AttributionSourceId.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.AttributionSourceId{ __meta__: term(), grounding_passage: Geminix.V1beta.GroundingPassageId.t(), semantic_retriever_chunk: Geminix.V1beta.SemanticRetrieverChunk.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.AttributionSourceId.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.