Geminix.V1beta.BatchEmbedContentsRequest (geminix v0.2.0)

Batch request to get embeddings from the model for a list of prompts.

Fields:

  • :requests (list of Geminix.V1beta.EmbedContentRequest.t/0) - Required. Embed requests for the batch. The model in each of these requests must match the model specified BatchEmbedContentsRequest.model.

Summary

Types

t()

@type t() :: %Geminix.V1beta.BatchEmbedContentsRequest{
  __meta__: term(),
  requests: [Geminix.V1beta.EmbedContentRequest.t()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.BatchEmbedContentsRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.