Geminix.V1beta.BatchEmbedContentsResponse (geminix v0.2.0)
The response to a BatchEmbedContentsRequest.
Fields:
:embeddings(list ofGeminix.V1beta.ContentEmbedding.t/0) - Output only. The embeddings for each request, in the same order as provided in the batch request.
Summary
Functions
Create a Geminix.V1beta.BatchEmbedContentsResponse.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.BatchEmbedContentsResponse{ __meta__: term(), embeddings: [Geminix.V1beta.ContentEmbedding.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.BatchEmbedContentsResponse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.