Geminix.V1beta.BatchEmbedTextRequest (geminix v0.2.0)

Batch request to get a text embedding from the model.

Fields:

  • :requests (list of Geminix.V1beta.EmbedTextRequest.t/0) - Optional. Embed requests for the batch. Only one of texts or requests can be set.
  • :texts (list of binary/0) - Optional. The free-form input texts that the model will turn into an embedding. The current limit is 100 texts, over which an error will be thrown.

Summary

Types

t()

@type t() :: %Geminix.V1beta.BatchEmbedTextRequest{
  __meta__: term(),
  requests: [Geminix.V1beta.EmbedTextRequest.t()],
  texts: [binary()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.BatchEmbedTextRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.