Geminix.V1beta.BatchGenerateContentRequest (geminix v0.2.0)
Request for a BatchGenerateContent operation.
Fields:
:batch(Geminix.V1beta.GenerateContentBatch.t/0) - Required. The batch to create.
Summary
Functions
Wait for the completion of a batch of requests, polling it periodically.
Wait for the completion of a batch of requests, polling it periodically. Raises if there is an error.
Create a Geminix.V1beta.BatchGenerateContentRequest.t/0 from a map returned
by the Gemini API.
Get the output of a batch and load it into memory.
Get the output of a batch and load it into memory. Raises in the case of error.
Start a new batch request.
Start a new batch request. Raises in case of error.
Update the state of a batch request by polling the API. Doesn't download the output of the request even if the batch has succeeded.
Types
@type t() :: %Geminix.V1beta.BatchGenerateContentRequest{ __meta__: term(), batch: Geminix.V1beta.GenerateContentBatch.t() }
Functions
Wait for the completion of a batch of requests, polling it periodically.
Wait for the completion of a batch of requests, polling it periodically. Raises if there is an error.
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.BatchGenerateContentRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.
Get the output of a batch and load it into memory.
Get the output of a batch and load it into memory. Raises in the case of error.
@spec start(binary(), [Geminix.V1beta.InlinedRequest.t()], keyword()) :: {:ok, t()} | {:error, any()}
Start a new batch request.
@spec start!(binary(), [Geminix.V1beta.InlinedRequest.t()], keyword()) :: t()
Start a new batch request. Raises in case of error.
Update the state of a batch request by polling the API. Doesn't download the output of the request even if the batch has succeeded.