Geminix.V1beta.BatchStats (geminix v0.2.0)

Stats about the batch.

Fields:

  • :failed_request_count (integer/0) - Output only. The number of requests that failed to be processed.
  • :pending_request_count (integer/0) - Output only. The number of requests that are still pending processing.
  • :request_count (integer/0) - Output only. The number of requests in the batch.
  • :successful_request_count (integer/0) - Output only. The number of requests that were successfully processed.

Summary

Functions

Create a Geminix.V1beta.BatchStats.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.BatchStats{
  __meta__: term(),
  failed_request_count: integer(),
  pending_request_count: integer(),
  request_count: integer(),
  successful_request_count: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.BatchStats.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.