Geminix.V1beta.CachedContentUsageMetadata (geminix v0.2.0)

Metadata on the usage of the cached content.

Fields:

  • :total_token_count (integer/0) - Total number of tokens that the cached content consumes.

Summary

Types

t()

@type t() :: %Geminix.V1beta.CachedContentUsageMetadata{
  __meta__: term(),
  total_token_count: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.CachedContentUsageMetadata.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.