Geminix.V1beta.ChunkingConfig (geminix v0.2.0)
Parameters for telling the service how to chunk the file. inspired by google3/cloud/ai/platform/extension/lib/retrieval/config/chunker_config.proto
Fields:
:white_space_config(Geminix.V1beta.WhiteSpaceConfig.t/0) - White space chunking configuration.
Summary
Functions
Create a Geminix.V1beta.ChunkingConfig.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.ChunkingConfig{ __meta__: term(), white_space_config: Geminix.V1beta.WhiteSpaceConfig.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ChunkingConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.