Geminix.V1beta.CodeExecutionResult (geminix v0.2.0)

Result of executing the ExecutableCode. Only generated when using the CodeExecution, and always follows a part containing the ExecutableCode.

Fields:

  • :outcome (binary/0) - Required. Outcome of the code execution.
  • :output (binary/0) - Optional. Contains stdout when code execution is successful, stderr or other description otherwise.

Summary

Types

t()

@type t() :: %Geminix.V1beta.CodeExecutionResult{
  __meta__: term(),
  outcome: binary(),
  output: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.CodeExecutionResult.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.