Geminix.V1beta.Condition (geminix v0.2.0)

Filter condition applicable to a single key.

Fields:

  • :numeric_value (number/0) - The numeric value to filter the metadata on.
  • :operation (binary/0) - Required. Operator applied to the given key-value pair to trigger the condition.
  • :string_value (binary/0) - The string value to filter the metadata on.

Summary

Functions

Create a Geminix.V1beta.Condition.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.Condition{
  __meta__: term(),
  numeric_value: number(),
  operation: binary(),
  string_value: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.Condition.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.