Geminix.V1beta.ContentFilter (geminix v0.2.0)

Content filtering metadata associated with processing a single request. ContentFilter contains a reason and an optional supporting string. The reason may be unspecified.

Fields:

  • :message (binary/0) - A string that describes the filtering behavior in more detail.
  • :reason (binary/0) - The reason content was blocked during request processing.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ContentFilter{
  __meta__: term(),
  message: binary(),
  reason: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ContentFilter.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.