Geminix.V1beta.CountMessageTokensRequest (geminix v0.2.0)
Counts the number of tokens in the prompt sent to a model. Models may tokenize text differently, so each model may return a different token_count.
Fields:
:prompt(Geminix.V1beta.MessagePrompt.t/0) - Required. The prompt, whose token count is to be returned.
Summary
Functions
Create a Geminix.V1beta.CountMessageTokensRequest.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.CountMessageTokensRequest{ __meta__: term(), prompt: Geminix.V1beta.MessagePrompt.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.CountMessageTokensRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.