Geminix.V1beta.CountTokensResponse (geminix v0.2.0)

A response from CountTokens. It returns the model's token_count for the prompt.

Fields:

  • :cache_tokens_details (list of Geminix.V1beta.ModalityTokenCount.t/0) - Output only. List of modalities that were processed in the cached content.
  • :cached_content_token_count (integer/0) - Number of tokens in the cached part of the prompt (the cached content).
  • :prompt_tokens_details (list of Geminix.V1beta.ModalityTokenCount.t/0) - Output only. List of modalities that were processed in the request input.
  • :total_tokens (integer/0) - The number of tokens that the Model tokenizes the prompt into. Always non-negative.

Summary

Types

t()

@type t() :: %Geminix.V1beta.CountTokensResponse{
  __meta__: term(),
  cache_tokens_details: [Geminix.V1beta.ModalityTokenCount.t()],
  cached_content_token_count: integer(),
  prompt_tokens_details: [Geminix.V1beta.ModalityTokenCount.t()],
  total_tokens: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.CountTokensResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.