Geminix.V1beta.CustomMetadata (geminix v0.2.0)

User provided metadata stored as key-value pairs.

Fields:

  • :key (binary/0) - Required. The key of the metadata to store.
  • :numeric_value (number/0) - The numeric value of the metadata to store.
  • :string_list_value (Geminix.V1beta.StringList.t/0) - The StringList value of the metadata to store.
  • :string_value (binary/0) - The string value of the metadata to store.

Summary

Types

t()

@type t() :: %Geminix.V1beta.CustomMetadata{
  __meta__: term(),
  key: binary(),
  numeric_value: number(),
  string_list_value: Geminix.V1beta.StringList.t(),
  string_value: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.CustomMetadata.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.