Geminix.V1beta.Dataset (geminix v0.2.0)

Dataset for training or validation.

Fields:

Summary

Functions

Create a Geminix.V1beta.Dataset.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.Dataset{
  __meta__: term(),
  examples: Geminix.V1beta.TuningExamples.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.Dataset.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.