Geminix.V1beta.DynamicRetrievalConfig (geminix v0.2.0)

Describes the options to customize dynamic retrieval.

Fields:

  • :dynamic_threshold (number/0) - The threshold to be used in dynamic retrieval. If not set, a system default value is used.
  • :mode (binary/0) - The mode of the predictor to be used in dynamic retrieval.

Summary

Types

t()

@type t() :: %Geminix.V1beta.DynamicRetrievalConfig{
  __meta__: term(),
  dynamic_threshold: number(),
  mode: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.DynamicRetrievalConfig.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.