Geminix.V1beta.EmbedContentBatch (geminix v0.2.0)

A resource representing a batch of EmbedContent requests.

Fields:

  • :batch_stats (Geminix.V1beta.EmbedContentBatchStats.t/0) - Output only. Stats about the batch.
  • :create_time (DateTime.t/0) - Output only. The time at which the batch was created.
  • :display_name (binary/0) - Required. The user-defined name of this batch.
  • :end_time (DateTime.t/0) - Output only. The time at which the batch processing completed.
  • :input_config (Geminix.V1beta.InputEmbedContentConfig.t/0) - Required. Input configuration of the instances on which batch processing are performed.
  • :model (binary/0) - Required. The name of the Model to use for generating the completion. Format: models/{model}.
  • :name (binary/0) - Output only. Identifier. Resource name of the batch. Format: batches/{batch_id}.
  • :output (Geminix.V1beta.EmbedContentBatchOutput.t/0) - Output only. The output of the batch request.
  • :priority (binary/0) - Optional. The priority of the batch. Batches with a higher priority value will be processed before batches with a lower priority value. Negative values are allowed. Default is 0.
  • :state (binary/0) - Output only. The state of the batch.
  • :update_time (DateTime.t/0) - Output only. The time at which the batch was last updated.

Summary

Types

t()

@type t() :: %Geminix.V1beta.EmbedContentBatch{
  __meta__: term(),
  batch_stats: Geminix.V1beta.EmbedContentBatchStats.t(),
  create_time: DateTime.t(),
  display_name: binary(),
  end_time: DateTime.t(),
  input_config: Geminix.V1beta.InputEmbedContentConfig.t(),
  model: binary(),
  name: binary(),
  output: Geminix.V1beta.EmbedContentBatchOutput.t(),
  priority: binary(),
  state: binary(),
  update_time: DateTime.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.EmbedContentBatch.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.