Geminix.V1beta.EmbedTextRequest (geminix v0.2.0)

Request to get a text embedding from the model.

Fields:

  • :model (binary/0) - Required. The model name to use with the format model=models/{model}.
  • :text (binary/0) - Optional. The free-form input text that the model will turn into an embedding.

Summary

Types

t()

@type t() :: %Geminix.V1beta.EmbedTextRequest{
  __meta__: term(),
  model: binary(),
  text: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.EmbedTextRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.