Geminix.V1beta.EmbedTextResponse (geminix v0.2.0)
The response to a EmbedTextRequest.
Fields:
:embedding(Geminix.V1beta.Embedding.t/0) - Output only. The embedding generated from the input text.
Summary
Functions
Create a Geminix.V1beta.EmbedTextResponse.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.EmbedTextResponse{ __meta__: term(), embedding: Geminix.V1beta.Embedding.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.EmbedTextResponse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.