Geminix.V1beta.Example (geminix v0.2.0)
An input/output example used to instruct the Model. It demonstrates how the model should respond or format its response.
Fields:
:input(Geminix.V1beta.Message.t/0) - Required. An example of an inputMessagefrom the user.:output(Geminix.V1beta.Message.t/0) - Required. An example of what the model should output given the input.
Summary
Functions
Create a Geminix.V1beta.Example.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.Example{ __meta__: term(), input: Geminix.V1beta.Message.t(), output: Geminix.V1beta.Message.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.Example.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.