Geminix.V1beta.ExecutableCode (geminix v0.2.0)

Code generated by the model that is meant to be executed, and the result returned to the model. Only generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Fields:

  • :code (binary/0) - Required. The code to be executed.
  • :language (binary/0) - Required. Programming language of the code.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ExecutableCode{
  __meta__: term(),
  code: binary(),
  language: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ExecutableCode.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.