Geminix.V1beta.FileData (geminix v0.2.0)

URI based data.

Fields:

  • :file_uri (binary/0) - Required. URI.
  • :mime_type (binary/0) - Optional. The IANA standard MIME type of the source data.

Summary

Functions

Create a Geminix.V1beta.FileData.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.FileData{
  __meta__: term(),
  file_uri: binary(),
  mime_type: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.FileData.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.