Geminix.V1beta.FileSearch (geminix v0.2.0)

The FileSearch tool that retrieves knowledge from Semantic Retrieval corpora. Files are imported to Semantic Retrieval corpora using the ImportFile API.

Fields:

  • :file_search_store_names (list of binary/0) - Required. The names of the file_search_stores to retrieve from. Example: fileSearchStores/my-file-search-store-123
  • :metadata_filter (binary/0) - Optional. Metadata filter to apply to the semantic retrieval documents and chunks.
  • :top_k (integer/0) - Optional. The number of semantic retrieval chunks to retrieve.

Summary

Functions

Create a Geminix.V1beta.FileSearch.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.FileSearch{
  __meta__: term(),
  file_search_store_names: [binary()],
  metadata_filter: binary(),
  top_k: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.FileSearch.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.