Geminix.V1beta.FileSearchStore (geminix v0.2.0)

A FileSearchStore is a collection of Documents.

Fields:

  • :active_documents_count (integer/0) - Output only. The number of documents in the FileSearchStore that are active and ready for retrieval.
  • :create_time (DateTime.t/0) - Output only. The Timestamp of when the FileSearchStore was created.
  • :display_name (binary/0) - Optional. The human-readable display name for the FileSearchStore. The display name must be no more than 512 characters in length, including spaces. Example: "Docs on Semantic Retriever"
  • :failed_documents_count (integer/0) - Output only. The number of documents in the FileSearchStore that have failed processing.
  • :name (binary/0) - Output only. Immutable. Identifier. The FileSearchStore resource name. It is an ID (name excluding the "fileSearchStores/" prefix) that can contain up to 40 characters that are lowercase alphanumeric or dashes (-). It is output only. The unique name will be derived from display_name along with a 12 character random suffix. Example: fileSearchStores/my-awesome-file-search-store-123a456b789c If display_name is not provided, the name will be randomly generated.
  • :pending_documents_count (integer/0) - Output only. The number of documents in the FileSearchStore that are being processed.
  • :size_bytes (binary/0) - Output only. The size of raw bytes ingested into the FileSearchStore. This is the total size of all the documents in the FileSearchStore.
  • :update_time (DateTime.t/0) - Output only. The Timestamp of when the FileSearchStore was last updated.

Summary

Types

t()

@type t() :: %Geminix.V1beta.FileSearchStore{
  __meta__: term(),
  active_documents_count: integer(),
  create_time: DateTime.t(),
  display_name: binary(),
  failed_documents_count: integer(),
  name: binary(),
  pending_documents_count: integer(),
  size_bytes: binary(),
  update_time: DateTime.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.FileSearchStore.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.