Geminix.V1beta.FunctionCallingConfig (geminix v0.2.0)
Configuration for specifying function calling behavior.
Fields:
:allowed_function_names(list ofbinary/0) - Optional. A set of function names that, when provided, limits the functions the model will call. This should only be set when the Mode is ANY or VALIDATED. Function names should match [FunctionDeclaration.name]. When set, model will predict a function call from only allowed function names.:mode(binary/0) - Optional. Specifies the mode in which function calling should execute. If unspecified, the default value will be set to AUTO.
Summary
Functions
Create a Geminix.V1beta.FunctionCallingConfig.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.FunctionCallingConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.