Geminix.V1beta.FunctionResponsePart (geminix v0.2.0)
A datatype containing media that is part of a FunctionResponse message. A FunctionResponsePart consists of data which has an associated datatype. A FunctionResponsePart can only contain one of the accepted types in FunctionResponsePart.data. A FunctionResponsePart must have a fixed IANA MIME type identifying the type and subtype of the media if the inline_data field is filled with raw bytes.
Fields:
:inline_data(Geminix.V1beta.FunctionResponseBlob.t/0) - Inline media bytes.
Summary
Functions
Create a Geminix.V1beta.FunctionResponsePart.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.FunctionResponsePart{ __meta__: term(), inline_data: Geminix.V1beta.FunctionResponseBlob.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.FunctionResponsePart.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.