Geminix.V1beta.GoogleAiGenerativelanguageV1betaSegment (geminix v0.2.0)

Segment of the content.

Fields:

  • :end_index (integer/0) - End index in the given Part, measured in bytes. Offset from the start of the Part, exclusive, starting at zero.
  • :part_index (integer/0) - The index of a Part object within its parent Content object.
  • :start_index (integer/0) - Start index in the given Part, measured in bytes. Offset from the start of the Part, inclusive, starting at zero.
  • :text (binary/0) - The text corresponding to the segment from the response.

Summary

Types

t()

@type t() :: %Geminix.V1beta.GoogleAiGenerativelanguageV1betaSegment{
  __meta__: term(),
  end_index: integer(),
  part_index: integer(),
  start_index: integer(),
  text: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.GoogleAiGenerativelanguageV1betaSegment.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.