Geminix.V1beta.GoogleSearch (geminix v0.2.0)
GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.
Fields:
:time_range_filter(Geminix.V1beta.Interval.t/0) - Optional. Filter search results to a specific time range. If customers set a start time, they must set an end time (and vice versa).
Summary
Functions
Create a Geminix.V1beta.GoogleSearch.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.GoogleSearch{ __meta__: term(), time_range_filter: Geminix.V1beta.Interval.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GoogleSearch.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.