Geminix.V1beta.GoogleSearchRetrieval (geminix v0.2.0)

Tool to retrieve public web data for grounding, powered by Google.

Fields:

Summary

Types

t()

@type t() :: %Geminix.V1beta.GoogleSearchRetrieval{
  __meta__: term(),
  dynamic_retrieval_config: Geminix.V1beta.DynamicRetrievalConfig.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.GoogleSearchRetrieval.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.