Geminix.V1beta.GroundingAttribution (geminix v0.2.0)
Attribution for a source that contributed to an answer.
Fields:
:content(Geminix.V1beta.Content.t/0) - Grounding source content that makes up this attribution.:source_id(Geminix.V1beta.AttributionSourceId.t/0) - Output only. Identifier for the source contributing to this attribution.
Summary
Functions
Create a Geminix.V1beta.GroundingAttribution.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.GroundingAttribution{ __meta__: term(), content: Geminix.V1beta.Content.t(), source_id: Geminix.V1beta.AttributionSourceId.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GroundingAttribution.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.