Geminix.V1beta.GroundingChunk (geminix v0.2.0)
Grounding chunk.
Fields:
:maps(Geminix.V1beta.Maps.t/0) - Optional. Grounding chunk from Google Maps.:retrieved_context(Geminix.V1beta.RetrievedContext.t/0) - Optional. Grounding chunk from context retrieved by the file search tool.:web(Geminix.V1beta.Web.t/0) - Grounding chunk from the web.
Summary
Functions
Create a Geminix.V1beta.GroundingChunk.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.GroundingChunk{ __meta__: term(), maps: Geminix.V1beta.Maps.t(), retrieved_context: Geminix.V1beta.RetrievedContext.t(), web: Geminix.V1beta.Web.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GroundingChunk.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.