Geminix.V1beta.GroundingPassage (geminix v0.2.0)
Passage included inline with a grounding configuration.
Fields:
:content(Geminix.V1beta.Content.t/0) - Content of the passage.:id(binary/0) - Identifier for the passage for attributing this passage in grounded answers.
Summary
Functions
Create a Geminix.V1beta.GroundingPassage.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.GroundingPassage{ __meta__: term(), content: Geminix.V1beta.Content.t(), id: binary() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GroundingPassage.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.