Geminix.V1beta.GroundingPassageId (geminix v0.2.0)

Identifier for a part within a GroundingPassage.

Fields:

  • :part_index (integer/0) - Output only. Index of the part within the GenerateAnswerRequest's GroundingPassage.content.
  • :passage_id (binary/0) - Output only. ID of the passage matching the GenerateAnswerRequest's GroundingPassage.id.

Summary

Types

t()

@type t() :: %Geminix.V1beta.GroundingPassageId{
  __meta__: term(),
  part_index: integer(),
  passage_id: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.GroundingPassageId.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.