Geminix.V1beta.ImportFileRequest (geminix v0.2.0)
Request for ImportFile to import a File API file with a FileSearchStore. LINT.IfChange(ImportFileRequest)
Fields:
:chunking_config(Geminix.V1beta.ChunkingConfig.t/0) - Optional. Config for telling the service how to chunk the file. If not provided, the service will use default parameters.:custom_metadata(list ofGeminix.V1beta.CustomMetadata.t/0) - Custom metadata to be associated with the file.:file_name(binary/0) - Required. The name of theFileto import. Example:files/abc-123
Summary
Functions
Create a Geminix.V1beta.ImportFileRequest.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.ImportFileRequest{ __meta__: term(), chunking_config: Geminix.V1beta.ChunkingConfig.t(), custom_metadata: [Geminix.V1beta.CustomMetadata.t()], file_name: binary() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ImportFileRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.