Geminix.V1beta.InlinedEmbedContentRequests (geminix v0.2.0)

The requests to be processed in the batch if provided as part of the batch creation request.

Fields:

Summary

Types

t()

@type t() :: %Geminix.V1beta.InlinedEmbedContentRequests{
  __meta__: term(),
  requests: [Geminix.V1beta.InlinedEmbedContentRequest.t()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.InlinedEmbedContentRequests.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.