Geminix.V1beta.InlinedEmbedContentResponse (geminix v0.2.0)
The response to a single request in the batch.
Fields:
:error(Geminix.V1beta.Status.t/0) - Output only. The error encountered while processing the request.:metadata(map/0) - Output only. The metadata associated with the request.:response(Geminix.V1beta.EmbedContentResponse.t/0) - Output only. The response to the request.
Summary
Functions
Create a Geminix.V1beta.InlinedEmbedContentResponse.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.InlinedEmbedContentResponse{ __meta__: term(), error: Geminix.V1beta.Status.t(), metadata: map(), response: Geminix.V1beta.EmbedContentResponse.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.InlinedEmbedContentResponse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.