Geminix.V1beta.InlinedRequest (geminix v0.2.0)
The request to be processed in the batch.
Fields:
:metadata(map/0) - Optional. The metadata to be associated with the request.:request(Geminix.V1beta.GenerateContentRequest.t/0) - Required. The request to be processed in the batch.
Summary
Functions
Create a Geminix.V1beta.InlinedRequest.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.InlinedRequest{ __meta__: term(), metadata: map(), request: Geminix.V1beta.GenerateContentRequest.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.InlinedRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.