Geminix.V1beta.InlinedRequests (geminix v0.2.0)
The requests to be processed in the batch if provided as part of the batch creation request.
Fields:
:requests(list ofGeminix.V1beta.InlinedRequest.t/0) - Required. The requests to be processed in the batch.
Summary
Functions
Create a Geminix.V1beta.InlinedRequests.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.InlinedRequests{ __meta__: term(), requests: [Geminix.V1beta.InlinedRequest.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.InlinedRequests.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.