Geminix.V1beta.InputEmbedContentConfig (geminix v0.2.0)
Configures the input to the batch request.
Fields:
:file_name(binary/0) - The name of theFilecontaining the input requests.:requests(Geminix.V1beta.InlinedEmbedContentRequests.t/0) - The requests to be processed in the batch.
Summary
Functions
Create a Geminix.V1beta.InputEmbedContentConfig.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.InputEmbedContentConfig{ __meta__: term(), file_name: binary(), requests: Geminix.V1beta.InlinedEmbedContentRequests.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.InputEmbedContentConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.