Geminix.V1beta.ListCachedContentsResponse (geminix v0.2.0)

Response with CachedContents list.

Fields:

  • :cached_contents (list of Geminix.V1beta.CachedContent.t/0) - List of cached contents.
  • :next_page_token (binary/0) - A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListCachedContentsResponse{
  __meta__: term(),
  cached_contents: [Geminix.V1beta.CachedContent.t()],
  next_page_token: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListCachedContentsResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.