Geminix.V1beta.ListCorporaResponse (geminix v0.2.0)

Response from ListCorpora containing a paginated list of Corpora. The results are sorted by ascending corpus.create_time.

Fields:

  • :corpora (list of Geminix.V1beta.Corpus.t/0) - The returned corpora.
  • :next_page_token (binary/0) - A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no more pages.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListCorporaResponse{
  __meta__: term(),
  corpora: [Geminix.V1beta.Corpus.t()],
  next_page_token: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListCorporaResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.