Geminix.V1beta.ListGeneratedFilesResponse (geminix v0.2.0)

Response for ListGeneratedFiles.

Fields:

  • :generated_files (list of Geminix.V1beta.GeneratedFile.t/0) - The list of GeneratedFiles.
  • :next_page_token (binary/0) - A token that can be sent as a page_token into a subsequent ListGeneratedFiles call.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListGeneratedFilesResponse{
  __meta__: term(),
  generated_files: [Geminix.V1beta.GeneratedFile.t()],
  next_page_token: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListGeneratedFilesResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.