Geminix.V1beta.ListModelsResponse (geminix v0.2.0)

Response from ListModel containing a paginated list of Models.

Fields:

  • :models (list of Geminix.V1beta.Model.t/0) - The returned Models.
  • :next_page_token (binary/0) - A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no more pages.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListModelsResponse{
  __meta__: term(),
  models: [Geminix.V1beta.Model.t()],
  next_page_token: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListModelsResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.