Geminix.V1beta.ListOperationsResponse (geminix v0.2.0)

The response message for Operations.ListOperations.

Fields:

  • :next_page_token (binary/0) - The standard List next-page token.
  • :operations (list of Geminix.V1beta.Operation.t/0) - A list of operations that matches the specified filter in the request.
  • :unreachable (list of binary/0) - Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListOperationsResponse{
  __meta__: term(),
  next_page_token: binary(),
  operations: [Geminix.V1beta.Operation.t()],
  unreachable: [binary()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListOperationsResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.