Geminix.V1beta.ListPermissionsResponse (geminix v0.2.0)

Response from ListPermissions containing a paginated list of permissions.

Fields:

  • :next_page_token (binary/0) - A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no more pages.
  • :permissions (list of Geminix.V1beta.Permission.t/0) - Returned permissions.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ListPermissionsResponse{
  __meta__: term(),
  next_page_token: binary(),
  permissions: [Geminix.V1beta.Permission.t()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ListPermissionsResponse.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.