Geminix.V1beta.LogprobsResult (geminix v0.2.0)
Logprobs Result
Fields:
:chosen_candidates(list ofGeminix.V1beta.LogprobsResultCandidate.t/0) - Length = total number of decoding steps. The chosen candidates may or may not be in top_candidates.:log_probability_sum(number/0) - Sum of log probabilities for all tokens.:top_candidates(list ofGeminix.V1beta.TopCandidates.t/0) - Length = total number of decoding steps.
Summary
Functions
Create a Geminix.V1beta.LogprobsResult.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.LogprobsResult{ __meta__: term(), chosen_candidates: [Geminix.V1beta.LogprobsResultCandidate.t()], log_probability_sum: number(), top_candidates: [Geminix.V1beta.TopCandidates.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.LogprobsResult.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.