Geminix.V1beta.Media (geminix v0.2.0)

Summary

Functions

Uploads data to a FileSearchStore, preprocesses and chunks before storing it in a FileSearchStore Document.

Functions

upload_to_file_search_store(file_search_store_name, request, opts \\ [])

@spec upload_to_file_search_store(
  binary(),
  Geminix.V1beta.UploadToFileSearchStoreRequest.t(),
  keyword()
) ::
  {:ok, Geminix.V1beta.CustomLongRunningOperation.t()}
  | {:error, {:invalid_data, Ecto.Changeset.t()}}
  | {:error, {:bad_request, Req.Response.t()}}

Uploads data to a FileSearchStore, preprocesses and chunks before storing it in a FileSearchStore Document.