Geminix.V1beta.ModalityTokenCount (geminix v0.2.0)

Represents token counting info for a single modality.

Fields:

  • :modality (binary/0) - The modality associated with this token count.
  • :token_count (integer/0) - Number of tokens.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ModalityTokenCount{
  __meta__: term(),
  modality: binary(),
  token_count: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ModalityTokenCount.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.