Geminix.V1beta.ModelStatus (geminix v0.2.0)

The status of the underlying model. This is used to indicate the stage of the underlying model and the retirement time if applicable.

Fields:

  • :message (binary/0) - A message explaining the model status.
  • :model_stage (binary/0) - The stage of the underlying model.
  • :retirement_time (DateTime.t/0) - The time at which the model will be retired.

Summary

Functions

Create a Geminix.V1beta.ModelStatus.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.ModelStatus{
  __meta__: term(),
  message: binary(),
  model_stage: binary(),
  retirement_time: DateTime.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ModelStatus.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.