Geminix.V1beta.MultiSpeakerVoiceConfig (geminix v0.2.0)
The configuration for the multi-speaker setup.
Fields:
:speaker_voice_configs(list ofGeminix.V1beta.SpeakerVoiceConfig.t/0) - Required. All the enabled speaker voices.
Summary
Functions
Create a Geminix.V1beta.MultiSpeakerVoiceConfig.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.MultiSpeakerVoiceConfig{ __meta__: term(), speaker_voice_configs: [Geminix.V1beta.SpeakerVoiceConfig.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.MultiSpeakerVoiceConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.