Geminix.V1beta.PredictLongRunningRequest (geminix v0.2.0)

Request message for [PredictionService.PredictLongRunning].

Fields:

  • :instances (list of any/0) - Required. The instances that are the input to the prediction call.
  • :parameters (any/0) - Optional. The parameters that govern the prediction call.

Summary

Types

t()

@type t() :: %Geminix.V1beta.PredictLongRunningRequest{
  __meta__: term(),
  instances: [any()],
  parameters: any()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.PredictLongRunningRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.