Geminix.V1beta.RegisterFilesRequest (geminix v0.2.0)

Request for RegisterFiles.

Fields:

  • :uris (list of binary/0) - Required. The Google Cloud Storage URIs to register. Example: gs://bucket/object.

Summary

Types

t()

@type t() :: %Geminix.V1beta.RegisterFilesRequest{__meta__: term(), uris: [binary()]}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.RegisterFilesRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.