Geminix.V1beta.RetrievalConfig (geminix v0.2.0)
Retrieval config.
Fields:
:language_code(binary/0) - Optional. The language code of the user. Language code for content. Use language tags defined by BCP47.:lat_lng(Geminix.V1beta.LatLng.t/0) - Optional. The location of the user.
Summary
Functions
Create a Geminix.V1beta.RetrievalConfig.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.RetrievalConfig{ __meta__: term(), language_code: binary(), lat_lng: Geminix.V1beta.LatLng.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.RetrievalConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.