Geminix.V1beta.RetrievalMetadata (geminix v0.2.0)
Metadata related to retrieval in the grounding flow.
Fields:
:google_search_dynamic_retrieval_score(number/0) - Optional. Score indicating how likely information from google search could help answer the prompt. The score is in the range [0, 1], where 0 is the least likely and 1 is the most likely. This score is only populated when google search grounding and dynamic retrieval is enabled. It will be compared to the threshold to determine whether to trigger google search.
Summary
Functions
Create a Geminix.V1beta.RetrievalMetadata.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.RetrievalMetadata.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.