Geminix.V1beta.ReviewSnippet (geminix v0.2.0)

Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.

Fields:

  • :google_maps_uri (binary/0) - A link that corresponds to the user review on Google Maps.
  • :review_id (binary/0) - The ID of the review snippet.
  • :title (binary/0) - Title of the review.

Summary

Types

t()

@type t() :: %Geminix.V1beta.ReviewSnippet{
  __meta__: term(),
  google_maps_uri: binary(),
  review_id: binary(),
  title: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.ReviewSnippet.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.