Geminix.V1beta.SafetySetting (geminix v0.2.0)

Safety setting, affecting the safety-blocking behavior. Passing a safety setting for a category changes the allowed probability that content is blocked.

Fields:

  • :category (binary/0) - Required. The category for this setting.
  • :threshold (binary/0) - Required. Controls the probability threshold at which harm is blocked.

Summary

Types

t()

@type t() :: %Geminix.V1beta.SafetySetting{
  __meta__: term(),
  category: binary(),
  threshold: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.SafetySetting.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.