Geminix.V1beta.SearchEntryPoint (geminix v0.2.0)

Google search entry point.

Fields:

  • :rendered_content (binary/0) - Optional. Web content snippet that can be embedded in a web page or an app webview.
  • :sdk_blob (binary/0) - Optional. Base64 encoded JSON representing array of tuple.

Summary

Types

t()

@type t() :: %Geminix.V1beta.SearchEntryPoint{
  __meta__: term(),
  rendered_content: binary(),
  sdk_blob: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.SearchEntryPoint.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.