Geminix.V1beta.SemanticRetrieverChunk (geminix v0.2.0)

Identifier for a Chunk retrieved via Semantic Retriever specified in the GenerateAnswerRequest using SemanticRetrieverConfig.

Fields:

  • :chunk (binary/0) - Output only. Name of the Chunk containing the attributed text. Example: corpora/123/documents/abc/chunks/xyz
  • :source (binary/0) - Output only. Name of the source matching the request's SemanticRetrieverConfig.source. Example: corpora/123 or corpora/123/documents/abc

Summary

Types

t()

@type t() :: %Geminix.V1beta.SemanticRetrieverChunk{
  __meta__: term(),
  chunk: binary(),
  source: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.SemanticRetrieverChunk.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.