Geminix.V1beta.SpeakerVoiceConfig (geminix v0.2.0)

The configuration for a single speaker in a multi speaker setup.

Fields:

  • :speaker (binary/0) - Required. The name of the speaker to use. Should be the same as in the prompt.
  • :voice_config (Geminix.V1beta.VoiceConfig.t/0) - Required. The configuration for the voice to use.

Summary

Types

t()

@type t() :: %Geminix.V1beta.SpeakerVoiceConfig{
  __meta__: term(),
  speaker: binary(),
  voice_config: Geminix.V1beta.VoiceConfig.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.SpeakerVoiceConfig.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.