Geminix.V1beta.StreamableHttpTransport (geminix v0.2.0)

A transport that can stream HTTP requests and responses. Next ID: 6

Fields:

  • :headers (map/0) - Optional: Fields for authentication headers, timeouts, etc., if needed.
  • :sse_read_timeout (binary/0) - Timeout for SSE read operations.
  • :terminate_on_close (boolean/0) - Whether to close the client session when the transport closes.
  • :timeout (binary/0) - HTTP timeout for regular operations.
  • :url (binary/0) - The full URL for the MCPServer endpoint. Example: "https://api.example.com/mcp"

Summary

Types

t()

@type t() :: %Geminix.V1beta.StreamableHttpTransport{
  __meta__: term(),
  headers: map(),
  sse_read_timeout: binary(),
  terminate_on_close: boolean(),
  timeout: binary(),
  url: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.StreamableHttpTransport.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.