Geminix.V1beta.StringList (geminix v0.2.0)
User provided string values assigned to a single metadata key.
Fields:
:values(list ofbinary/0) - The string values of the metadata to store.
Summary
Functions
Create a Geminix.V1beta.StringList.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.StringList.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.