Geminix.V1beta.TextCompletion (geminix v0.2.0)

Output text returned from a model.

Fields:

  • :citation_metadata (Geminix.V1beta.CitationMetadata.t/0) - Output only. Citation information for model-generated output in this TextCompletion. This field may be populated with attribution information for any text included in the output.
  • :output (binary/0) - Output only. The generated text returned from the model.
  • :safety_ratings (list of Geminix.V1beta.SafetyRating.t/0) - Ratings for the safety of a response. There is at most one rating per category.

Summary

Types

t()

@type t() :: %Geminix.V1beta.TextCompletion{
  __meta__: term(),
  citation_metadata: Geminix.V1beta.CitationMetadata.t(),
  output: binary(),
  safety_ratings: [Geminix.V1beta.SafetyRating.t()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TextCompletion.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.