Geminix.V1beta.ToolConfig (geminix v0.2.0)
The Tool configuration containing parameters for specifying Tool use in the request.
Fields:
:function_calling_config(Geminix.V1beta.FunctionCallingConfig.t/0) - Optional. Function calling config.:retrieval_config(Geminix.V1beta.RetrievalConfig.t/0) - Optional. Retrieval config.
Summary
Functions
Create a Geminix.V1beta.ToolConfig.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.ToolConfig{ __meta__: term(), function_calling_config: Geminix.V1beta.FunctionCallingConfig.t(), retrieval_config: Geminix.V1beta.RetrievalConfig.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ToolConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.