Geminix.V1beta.TunedModel (geminix v0.2.0)

A fine-tuned model created using ModelService.CreateTunedModel.

Fields:

  • :base_model (binary/0) - Immutable. The name of the Model to tune. Example: models/gemini-1.5-flash-001
  • :create_time (DateTime.t/0) - Output only. The timestamp when this model was created.
  • :description (binary/0) - Optional. A short description of this model.
  • :display_name (binary/0) - Optional. The name to display for this model in user interfaces. The display name must be up to 40 characters including spaces.
  • :name (binary/0) - Output only. The tuned model name. A unique name will be generated on create. Example: tunedModels/az2mb0bpw6i If display_name is set on create, the id portion of the name will be set by concatenating the words of the display_name with hyphens and adding a random portion for uniqueness. Example: display_name = Sentence Translator name = tunedModels/sentence-translator-u3b7m
  • :reader_project_numbers (list of binary/0) - Optional. List of project numbers that have read access to the tuned model.
  • :state (binary/0) - Output only. The state of the tuned model.
  • :temperature (number/0) - Optional. Controls the randomness of the output. Values can range over [0.0,1.0], inclusive. A value closer to 1.0 will produce responses that are more varied, while a value closer to 0.0 will typically result in less surprising responses from the model. This value specifies default to be the one used by the base model while creating the model.
  • :top_k (integer/0) - Optional. For Top-k sampling. Top-k sampling considers the set of top_k most probable tokens. This value specifies default to be used by the backend while making the call to the model. This value specifies default to be the one used by the base model while creating the model.
  • :top_p (number/0) - Optional. For Nucleus sampling. Nucleus sampling considers the smallest set of tokens whose probability sum is at least top_p. This value specifies default to be the one used by the base model while creating the model.
  • :tuned_model_source (Geminix.V1beta.TunedModelSource.t/0) - Optional. TunedModel to use as the starting point for training the new model.
  • :tuning_task (Geminix.V1beta.TuningTask.t/0) - Required. The tuning task that creates the tuned model.
  • :update_time (DateTime.t/0) - Output only. The timestamp when this model was updated.

Summary

Functions

Create a Geminix.V1beta.TunedModel.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.TunedModel{
  __meta__: term(),
  base_model: binary(),
  create_time: DateTime.t(),
  description: binary(),
  display_name: binary(),
  name: binary(),
  reader_project_numbers: [binary()],
  state: binary(),
  temperature: number(),
  top_k: integer(),
  top_p: number(),
  tuned_model_source: Geminix.V1beta.TunedModelSource.t(),
  tuning_task: Geminix.V1beta.TuningTask.t(),
  update_time: DateTime.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TunedModel.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.