Geminix.V1beta.TunedModelSource (geminix v0.2.0)

Tuned model as a source for training a new model.

Fields:

  • :base_model (binary/0) - Output only. The name of the base Model this TunedModel was tuned from. Example: models/gemini-1.5-flash-001
  • :tuned_model (binary/0) - Immutable. The name of the TunedModel to use as the starting point for training the new model. Example: tunedModels/my-tuned-model

Summary

Types

t()

@type t() :: %Geminix.V1beta.TunedModelSource{
  __meta__: term(),
  base_model: binary(),
  tuned_model: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TunedModelSource.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.