Geminix.V1beta.TuningExample (geminix v0.2.0)

A single example for tuning.

Fields:

  • :output (binary/0) - Required. The expected model output.
  • :text_input (binary/0) - Optional. Text model input.

Summary

Types

t()

@type t() :: %Geminix.V1beta.TuningExample{
  __meta__: term(),
  output: binary(),
  text_input: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TuningExample.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.