Geminix.V1beta.TuningExamples (geminix v0.2.0)

A set of tuning examples. Can be training or validation data.

Fields:

  • :examples (list of Geminix.V1beta.TuningExample.t/0) - The examples. Example input can be for text or discuss, but all examples in a set must be of the same type.

Summary

Types

t()

@type t() :: %Geminix.V1beta.TuningExamples{
  __meta__: term(),
  examples: [Geminix.V1beta.TuningExample.t()]
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TuningExamples.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.