Geminix.V1beta.TuningSnapshot (geminix v0.2.0)

Record for a single tuning step.

Fields:

  • :compute_time (DateTime.t/0) - Output only. The timestamp when this metric was computed.
  • :epoch (integer/0) - Output only. The epoch this step was part of.
  • :mean_loss (number/0) - Output only. The mean loss of the training examples for this step.
  • :step (integer/0) - Output only. The tuning step.

Summary

Types

t()

@type t() :: %Geminix.V1beta.TuningSnapshot{
  __meta__: term(),
  compute_time: DateTime.t(),
  epoch: integer(),
  mean_loss: number(),
  step: integer()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TuningSnapshot.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.