Geminix.V1beta.TuningTask (geminix v0.2.0)

Tuning tasks that create tuned models.

Fields:

Summary

Functions

Create a Geminix.V1beta.TuningTask.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.TuningTask{
  __meta__: term(),
  complete_time: DateTime.t(),
  hyperparameters: Geminix.V1beta.Hyperparameters.t(),
  snapshots: [Geminix.V1beta.TuningSnapshot.t()],
  start_time: DateTime.t(),
  training_data: Geminix.V1beta.Dataset.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.TuningTask.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.