Geminix.V1beta.UploadToFileSearchStoreRequest (geminix v0.2.0)

Request for UploadToFileSearchStore.

Fields:

  • :chunking_config (Geminix.V1beta.ChunkingConfig.t/0) - Optional. Config for telling the service how to chunk the data. If not provided, the service will use default parameters.
  • :custom_metadata (list of Geminix.V1beta.CustomMetadata.t/0) - Custom metadata to be associated with the data.
  • :display_name (binary/0) - Optional. Display name of the created document.
  • :mime_type (binary/0) - Optional. MIME type of the data. If not provided, it will be inferred from the uploaded content.

Summary

Types

t()

@type t() :: %Geminix.V1beta.UploadToFileSearchStoreRequest{
  __meta__: term(),
  chunking_config: Geminix.V1beta.ChunkingConfig.t(),
  custom_metadata: [Geminix.V1beta.CustomMetadata.t()],
  display_name: binary(),
  mime_type: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.UploadToFileSearchStoreRequest.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.