Geminix.V1beta.UrlMetadata (geminix v0.2.0)

Context of the a single url retrieval.

Fields:

  • :retrieved_url (binary/0) - Retrieved url by the tool.
  • :url_retrieval_status (binary/0) - Status of the url retrieval.

Summary

Functions

Create a Geminix.V1beta.UrlMetadata.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.UrlMetadata{
  __meta__: term(),
  retrieved_url: binary(),
  url_retrieval_status: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.UrlMetadata.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.