Geminix.V1beta.VideoFileMetadata (geminix v0.2.0)
Metadata for a video File.
Fields:
:video_duration(binary/0) - Duration of the video.
Summary
Functions
Create a Geminix.V1beta.VideoFileMetadata.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.VideoFileMetadata.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.