Geminix.V1beta.VideoMetadata (geminix v0.2.0)

Metadata describes the input video content.

Fields:

  • :end_offset (binary/0) - Optional. The end offset of the video.
  • :fps (number/0) - Optional. The frame rate of the video sent to the model. If not specified, the default value will be 1.0. The fps range is (0.0, 24.0].
  • :start_offset (binary/0) - Optional. The start offset of the video.

Summary

Types

t()

@type t() :: %Geminix.V1beta.VideoMetadata{
  __meta__: term(),
  end_offset: binary(),
  fps: number(),
  start_offset: binary()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.VideoMetadata.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.