Geminix.V1beta.VoiceConfig (geminix v0.2.0)

The configuration for the voice to use.

Fields:

Summary

Functions

Create a Geminix.V1beta.VoiceConfig.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.VoiceConfig{
  __meta__: term(),
  prebuilt_voice_config: Geminix.V1beta.PrebuiltVoiceConfig.t()
}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.VoiceConfig.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.