Geminix.V1beta.Web (geminix v0.2.0)

Chunk from the web.

Fields:

  • :title (binary/0) - Title of the chunk.
  • :uri (binary/0) - URI reference of the chunk.

Summary

Functions

Create a Geminix.V1beta.Web.t/0 from a map returned by the Gemini API.

Types

t()

@type t() :: %Geminix.V1beta.Web{__meta__: term(), title: binary(), uri: binary()}

Functions

from_map(schema \\ %__MODULE__{}, map)

@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}

Create a Geminix.V1beta.Web.t/0 from a map returned by the Gemini API.

Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.