Geminix.Config (geminix v0.2.0)
Config options for Geminix functions.
Usually, these config options can be given in the following ways:
- As keyword arguments to the functions
- As a key in the process dictionary
- As keys in the
:geminixapplication environment
Each way of supplying config options overrides those lower on the list (i.e. keyword arguments override options in the process dictionarty, which override options given in the application config).
Summary
Functions
Run the function with the ignore_cache set to true or false
in the process dictionary.
Run the function with the given plug stored in the process dictionary.