Geminix.V1beta.BatchEmbedTextRequest (geminix v0.2.0)
Batch request to get a text embedding from the model.
Fields:
:requests(list ofGeminix.V1beta.EmbedTextRequest.t/0) - Optional. Embed requests for the batch. Only one oftextsorrequestscan be set.:texts(list ofbinary/0) - Optional. The free-form input texts that the model will turn into an embedding. The current limit is 100 texts, over which an error will be thrown.
Summary
Functions
Create a Geminix.V1beta.BatchEmbedTextRequest.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.BatchEmbedTextRequest{ __meta__: term(), requests: [Geminix.V1beta.EmbedTextRequest.t()], texts: [binary()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.BatchEmbedTextRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.