Geminix.V1beta.CodeExecution (geminix v0.2.0)
Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult which are only generated when using this tool.
Fields:
Summary
Functions
Create a Geminix.V1beta.CodeExecution.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.CodeExecution{__meta__: term()}
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.CodeExecution.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.