Geminix.V1beta.ComputerUse (geminix v0.2.0)
Computer Use tool type.
Fields:
:environment(binary/0) - Required. The environment being operated.:excluded_predefined_functions(list ofbinary/0) - Optional. By default, predefined functions are included in the final model call. Some of them can be explicitly excluded from being automatically included. This can serve two purposes: 1. Using a more restricted / different action space. 2. Improving the definitions / instructions of predefined functions.
Summary
Functions
Create a Geminix.V1beta.ComputerUse.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ComputerUse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.