Geminix.V1beta.Empty (geminix v0.2.0)
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Fields:
Summary
Functions
Create a Geminix.V1beta.Empty.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.Empty{__meta__: term()}
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.Empty.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.