Geminix.V1beta.GoogleAiGenerativelanguageV1betaGroundingSupport (geminix v0.2.0)
Grounding support.
Fields:
:confidence_scores(list ofnumber/0) - Optional. Confidence score of the support references. Ranges from 0 to 1. 1 is the most confident. This list must have the same size as the grounding_chunk_indices.:grounding_chunk_indices(list ofinteger/0) - Optional. A list of indices (into 'grounding_chunk' inresponse.candidate.grounding_metadata) specifying the citations associated with the claim. For instance [1,3,4] means that grounding_chunk[1], grounding_chunk[3], grounding_chunk[4] are the retrieved content attributed to the claim. If the response is streaming, the grounding_chunk_indices refer to the indices across all responses. It is the client's responsibility to accumulate the grounding chunks from all responses (while maintaining the same order).:segment(Geminix.V1beta.GoogleAiGenerativelanguageV1betaSegment.t/0) - Segment of the content this support belongs to.
Summary
Functions
Create a Geminix.V1beta.GoogleAiGenerativelanguageV1betaGroundingSupport.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.GoogleAiGenerativelanguageV1betaGroundingSupport{ __meta__: term(), confidence_scores: [number()], grounding_chunk_indices: [integer()], segment: Geminix.V1beta.GoogleAiGenerativelanguageV1betaSegment.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GoogleAiGenerativelanguageV1betaGroundingSupport.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.