Geminix.V1beta.GoogleMaps (geminix v0.2.0)
The GoogleMaps Tool that provides geospatial context for the user's query.
Fields:
:enable_widget(boolean/0) - Optional. Whether to return a widget context token in the GroundingMetadata of the response. Developers can use the widget context token to render a Google Maps widget with geospatial context related to the places that the model references in the response.
Summary
Functions
Create a Geminix.V1beta.GoogleMaps.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.GoogleMaps.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.