Geminix.V1beta.InputFeedback (geminix v0.2.0)
Feedback related to the input data used to answer the question, as opposed to the model-generated response to the question.
Fields:
:block_reason(binary/0) - Optional. If set, the input was blocked and no candidates are returned. Rephrase the input.:safety_ratings(list ofGeminix.V1beta.SafetyRating.t/0) - Ratings for safety of the input. There is at most one rating per category.
Summary
Functions
Create a Geminix.V1beta.InputFeedback.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.InputFeedback{ __meta__: term(), block_reason: binary(), safety_ratings: [Geminix.V1beta.SafetyRating.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.InputFeedback.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.