Geminix.V1beta.ListDocumentsResponse (geminix v0.2.0)
Response from ListDocuments containing a paginated list of Documents. The Documents are sorted by ascending document.create_time.
Fields:
:documents(list ofGeminix.V1beta.Document.t/0) - The returnedDocuments.:next_page_token(binary/0) - A token, which can be sent aspage_tokento retrieve the next page. If this field is omitted, there are no more pages.
Summary
Functions
Create a Geminix.V1beta.ListDocumentsResponse.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.ListDocumentsResponse{ __meta__: term(), documents: [Geminix.V1beta.Document.t()], next_page_token: binary() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ListDocumentsResponse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.