Geminix.V1beta.ListOperationsResponse (geminix v0.2.0)
The response message for Operations.ListOperations.
Fields:
:next_page_token(binary/0) - The standard List next-page token.:operations(list ofGeminix.V1beta.Operation.t/0) - A list of operations that matches the specified filter in the request.:unreachable(list ofbinary/0) - Unordered list. Unreachable resources. Populated when the request setsListOperationsRequest.return_partial_successand reads across collections. For example, when attempting to list all resources across all supported locations.
Summary
Functions
Create a Geminix.V1beta.ListOperationsResponse.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.ListOperationsResponse{ __meta__: term(), next_page_token: binary(), operations: [Geminix.V1beta.Operation.t()], unreachable: [binary()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ListOperationsResponse.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.