Geminix.V1beta.McpServer (geminix v0.2.0)
A MCPServer is a server that can be called by the model to perform actions. It is a server that implements the MCP protocol. Next ID: 5
Fields:
:name(binary/0) - The name of the MCPServer.:streamable_http_transport(Geminix.V1beta.StreamableHttpTransport.t/0) - A transport that can stream HTTP requests and responses.
Summary
Functions
Create a Geminix.V1beta.McpServer.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.McpServer{ __meta__: term(), name: binary(), streamable_http_transport: Geminix.V1beta.StreamableHttpTransport.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.McpServer.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.