Geminix.V1beta.PromptFeedback (geminix v0.2.0)
A set of the feedback metadata the prompt specified in GenerateContentRequest.content.
Fields:
:block_reason(binary/0) - Optional. If set, the prompt was blocked and no candidates are returned. Rephrase the prompt.:safety_ratings(list ofGeminix.V1beta.SafetyRating.t/0) - Ratings for safety of the prompt. There is at most one rating per category.
Summary
Functions
Create a Geminix.V1beta.PromptFeedback.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.PromptFeedback{ __meta__: term(), block_reason: binary(), safety_ratings: [Geminix.V1beta.SafetyRating.t()] }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.PromptFeedback.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.