Geminix.V1beta.RetrievedContext (geminix v0.2.0)
Chunk from context retrieved by the file search tool.
Fields:
:file_search_store(binary/0) - Optional. Name of theFileSearchStorecontaining the document. Example:fileSearchStores/123:text(binary/0) - Optional. Text of the chunk.:title(binary/0) - Optional. Title of the document.:uri(binary/0) - Optional. URI reference of the semantic retrieval document.
Summary
Functions
Create a Geminix.V1beta.RetrievedContext.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.RetrievedContext.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.