Geminix.V1beta.ThinkingConfig (geminix v0.2.0)
Config for thinking features.
Fields:
:include_thoughts(boolean/0) - Indicates whether to include thoughts in the response. If true, thoughts are returned only when available.:thinking_budget(integer/0) - The number of thoughts tokens that the model should generate.:thinking_level(binary/0) - Optional. Controls the maximum depth of the model's internal reasoning process before it produces a response. If not specified, the default is HIGH. Recommended for Gemini 3 or later models. Use with earlier models results in an error.
Summary
Functions
Create a Geminix.V1beta.ThinkingConfig.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.ThinkingConfig.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.