Geminix.V1beta.TransferOwnershipRequest (geminix v0.2.0)
Request to transfer the ownership of the tuned model.
Fields:
:email_address(binary/0) - Required. The email address of the user to whom the tuned model is being transferred to.
Summary
Functions
Create a Geminix.V1beta.TransferOwnershipRequest.t/0 from a map returned
by the Gemini API.
Types
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.TransferOwnershipRequest.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.