Geminix.V1beta.TuningTask (geminix v0.2.0)
Tuning tasks that create tuned models.
Fields:
:complete_time(DateTime.t/0) - Output only. The timestamp when tuning this model completed.:hyperparameters(Geminix.V1beta.Hyperparameters.t/0) - Immutable. Hyperparameters controlling the tuning process. If not provided, default values will be used.:snapshots(list ofGeminix.V1beta.TuningSnapshot.t/0) - Output only. Metrics collected during tuning.:start_time(DateTime.t/0) - Output only. The timestamp when tuning this model started.:training_data(Geminix.V1beta.Dataset.t/0) - Required. Input only. Immutable. The model training data.
Summary
Functions
Create a Geminix.V1beta.TuningTask.t/0 from a map returned
by the Gemini API.
Types
@type t() :: %Geminix.V1beta.TuningTask{ __meta__: term(), complete_time: DateTime.t(), hyperparameters: Geminix.V1beta.Hyperparameters.t(), snapshots: [Geminix.V1beta.TuningSnapshot.t()], start_time: DateTime.t(), training_data: Geminix.V1beta.Dataset.t() }
Functions
@spec from_map(t(), map()) :: {:ok, t()} | {:error, Ecto.Changeset.t()}
Create a Geminix.V1beta.TuningTask.t/0 from a map returned
by the Gemini API.
Sometimes, this function should not be applied to the full response body, but instead it should be applied to the correct part of the map in the response body. This depends on the concrete API call.